summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libbsp/m68k/mvme167/timer/timer.c
diff options
context:
space:
mode:
Diffstat (limited to 'c/src/lib/libbsp/m68k/mvme167/timer/timer.c')
-rw-r--r--c/src/lib/libbsp/m68k/mvme167/timer/timer.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/c/src/lib/libbsp/m68k/mvme167/timer/timer.c b/c/src/lib/libbsp/m68k/mvme167/timer/timer.c
index 740fb2efe2..5e86243763 100644
--- a/c/src/lib/libbsp/m68k/mvme167/timer/timer.c
+++ b/c/src/lib/libbsp/m68k/mvme167/timer/timer.c
@@ -1,9 +1,9 @@
/* timer.c
*
* This file manages the benchmark timer used by the RTEMS Timing Test Suite.
* Each measured time period is demarcated by calls to Timer_initialize() and
* Read_timer(). Read_timer() usually returns the number of microseconds
* since Timer_initialize() exitted.
*
* These functions are prototyped in rtems/c/src/lib/include/timerdrv.h and
* must be implemented as part of the BSP.
@@ -46,7 +46,7 @@ uint32_t Ttimer_val;
* in the .bss section and on that section being explicitly zeroed at boot
* time.
*/
-rtems_boolean Timer_driver_Find_average_overhead;
+rtems_boolean benchmark_timerfind_average_overhead;
rtems_isr timerisr(void);
@@ -70,7 +70,7 @@ rtems_isr timerisr(void);
* boot ROM to provide a 1 MHz clock to the timers. For a 25 MHz MVME167, the
* prescaler value should be 0xE7 (page 2-63).
*/
-void Timer_initialize(void)
+void benchmark_timerinitialize(void)
{
(void) set_vector( timerisr, TIMER_VECTOR, 0 );
@@ -105,13 +105,13 @@ void Timer_initialize(void)
* LEAST_VALID is the lowest number this routine should trust. Numbers
* below this are "noise" and zero is returned.
*/
-int Read_timer(void)
+int benchmark_timerread(void)
{
uint32_t total;
total = (Ttimer_val * TICK_INTERVAL) + lcsr->timer_cnt_1;
- if ( Timer_driver_Find_average_overhead )
+ if ( benchmark_timerfind_average_overhead )
return total; /* in one microsecond units */
if ( total < LEAST_VALID )
@@ -128,22 +128,22 @@ int Read_timer(void)
*
* Output parameters: time in microseconds
*/
-rtems_status_code Empty_function( void )
+rtems_status_code benchmark_timerempty_function( void )
{
return RTEMS_SUCCESSFUL;
}
/*
* This routine sets the Timer_driver_Find_average_overhead flag in this
* module.
*
* Input parameters: NONE
*
* Output parameters: time in microseconds
*/
-void Set_find_average_overhead(
+void benchmark_timerdisable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timerfind_average_overhead = find_flag;
}
@@ -1,9 +1,9 @@
*
* This file manages the benchmark timer used by the RTEMS Timing Test Suite.
- * Each measured time period is demarcated by calls to Timer_initialize() and
- * Read_timer(). Read_timer() usually returns the number of microseconds
- * since Timer_initialize() exitted.
+ * Each measured time period is demarcated by calls to benchmark_timerinitialize() and
+ * benchmark_timerread(). benchmark_timerread() usually returns the number of microseconds
+ * since benchmark_timerinitialize() exitted.
*
* These functions are prototyped in rtems/c/src/lib/include/timerdrv.h and
@@ -128,22 +128,22 @@ int Read_timer(void)
}
/*
- * This routine sets the Timer_driver_Find_average_overhead flag in this
+ * This routine sets the benchmark_timerfind_average_overhead flag in this
* module.
*